"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const graphql_request_1 = require("graphql-request");
const request_promise_native_1 = __importDefault(require("request-promise-native"));
const config_1 = __importDefault(require("../lib/config"));
const interfaces_1 = require("./interfaces");
class Helper {
    static credit;
    static uris;
    static endpoint;
    static setCredit(credit) {
        Helper.credit = credit;
    }
    static setUris(uris) {
        Helper.uris = uris;
    }
    static setEndpoint(endpoint) {
        Helper.endpoint = endpoint;
    }
    static parseCookie(cookies, key) {
        if (!cookies) {
            return "";
        }
        for (let ix = 0; ix !== cookies.length; ++ix) {
            const result = cookies[ix].match(new RegExp(`${key}=(.+?);`));
            if (result) {
                return result[1] || "";
            }
        }
        return "";
    }
    static statusMap(status) {
        switch (status) {
            case "ac":
                return interfaces_1.ProblemStatus.Accept;
            case "notac":
                return interfaces_1.ProblemStatus.NotAccept;
            case null:
                return interfaces_1.ProblemStatus.NotStart;
            default:
                return interfaces_1.ProblemStatus.NotStart;
        }
    }
    static difficultyMap(difficulty) {
        switch (difficulty) {
            case "Easy":
                return interfaces_1.ProblemDifficulty.Easy;
            case "Medium":
                return interfaces_1.ProblemDifficulty.Medium;
            case "Hard":
                return interfaces_1.ProblemDifficulty.Hard;
            default:
                return interfaces_1.ProblemDifficulty.Easy;
        }
    }
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    static async HttpRequest(options) {
        return await (0, request_promise_native_1.default)({
            method: options.method || "GET",
            uri: options.url,
            followRedirect: false,
            headers: {
                Cookie: Helper.credit
                    ? `LEETCODE_SESSION=${Helper.credit.session};csrftoken=${Helper.credit.csrfToken}`
                    : "",
                "X-Requested-With": "XMLHttpRequest",
                "X-CSRFToken": Helper.credit ? Helper.credit.csrfToken : "",
                Referer: options.referer || Helper.uris.base,
            },
            resolveWithFullResponse: options.resolveWithFullResponse || false,
            form: options.form || null,
            body: JSON.stringify(options.body) || "",
            encoding: options.encoding || "utf-8",
        });
    }
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    static async GraphQLRequest(options) {
        const client = new graphql_request_1.GraphQLClient(Helper.uris.graphql, {
            headers: {
                Origin: options.origin || Helper.uris.base,
                Referer: options.referer || Helper.uris.base,
                Cookie: `LEETCODE_SESSION=${Helper.credit.session};csrftoken=${Helper.credit.csrfToken};`,
                "X-Requested-With": "XMLHttpRequest",
                "X-CSRFToken": Helper.credit.csrfToken,
            },
        });
        return await client.request(options.query, options.variables || {});
    }
    static switchEndPoint(endPoint) {
        Helper.setEndpoint(endPoint);
        const uris = (() => {
            switch (endPoint) {
                case interfaces_1.EndPoint.US:
                    return config_1.default.uri.us;
                case interfaces_1.EndPoint.CN:
                    return config_1.default.uri.cn;
            }
        })();
        Helper.setUris(uris);
    }
}
exports.default = Helper;
//# sourceMappingURL=helper.js.map